# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/text_sentiment.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    classification_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/text_sentiment.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1B\022TextSentimentProtoZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n6google/cloud/automl_v1beta1/proto/text_sentiment.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x36google/cloud/automl_v1beta1/proto/classification.proto",\n\x17TextSentimentAnnotation\x12\x11\n\tsentiment\x18\x01 \x01(\x05"\xc1\x02\n\x1eTextSentimentEvaluationMetrics\x12\x11\n\tprecision\x18\x01 \x01(\x02\x12\x0e\n\x06recall\x18\x02 \x01(\x02\x12\x10\n\x08\x66\x31_score\x18\x03 \x01(\x02\x12\x1b\n\x13mean_absolute_error\x18\x04 \x01(\x02\x12\x1a\n\x12mean_squared_error\x18\x05 \x01(\x02\x12\x14\n\x0clinear_kappa\x18\x06 \x01(\x02\x12\x17\n\x0fquadratic_kappa\x18\x07 \x01(\x02\x12\x66\n\x10\x63onfusion_matrix\x18\x08 \x01(\x0b\x32L.google.cloud.automl.v1beta1.ClassificationEvaluationMetrics.ConfusionMatrix\x12\x1a\n\x12\x61nnotation_spec_id\x18\t \x03(\tB\x96\x01\n\x1f\x63om.google.cloud.automl.v1beta1B\x12TextSentimentProtoZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2.DESCRIPTOR,
    ],
)


_TEXTSENTIMENTANNOTATION = _descriptor.Descriptor(
    name="TextSentimentAnnotation",
    full_name="google.cloud.automl.v1beta1.TextSentimentAnnotation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="sentiment",
            full_name="google.cloud.automl.v1beta1.TextSentimentAnnotation.sentiment",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=173,
    serialized_end=217,
)


_TEXTSENTIMENTEVALUATIONMETRICS = _descriptor.Descriptor(
    name="TextSentimentEvaluationMetrics",
    full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="precision",
            full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics.precision",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="recall",
            full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics.recall",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="f1_score",
            full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics.f1_score",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="mean_absolute_error",
            full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics.mean_absolute_error",
            index=3,
            number=4,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="mean_squared_error",
            full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics.mean_squared_error",
            index=4,
            number=5,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="linear_kappa",
            full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics.linear_kappa",
            index=5,
            number=6,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="quadratic_kappa",
            full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics.quadratic_kappa",
            index=6,
            number=7,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="confusion_matrix",
            full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics.confusion_matrix",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="annotation_spec_id",
            full_name="google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics.annotation_spec_id",
            index=8,
            number=9,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=220,
    serialized_end=541,
)

_TEXTSENTIMENTEVALUATIONMETRICS.fields_by_name[
    "confusion_matrix"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2._CLASSIFICATIONEVALUATIONMETRICS_CONFUSIONMATRIX
)
DESCRIPTOR.message_types_by_name["TextSentimentAnnotation"] = _TEXTSENTIMENTANNOTATION
DESCRIPTOR.message_types_by_name[
    "TextSentimentEvaluationMetrics"
] = _TEXTSENTIMENTEVALUATIONMETRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextSentimentAnnotation = _reflection.GeneratedProtocolMessageType(
    "TextSentimentAnnotation",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTSENTIMENTANNOTATION,
        __module__="google.cloud.automl_v1beta1.proto.text_sentiment_pb2",
        __doc__="""Contains annotation details specific to text sentiment.
  
  
  Attributes:
      sentiment:
          Output only. The sentiment with the semantic, as given to the 
          [AutoMl.ImportData][google.cloud.automl.v1beta1.AutoMl.ImportD
          ata] when populating the dataset from which the model used for
          the prediction had been trained. The sentiment values are
          between 0 and
          Dataset.text\_sentiment\_dataset\_metadata.sentiment\_max
          (inclusive), with higher value meaning more positive
          sentiment. They are completely relative, i.e. 0 means least
          positive sentiment and sentiment\_max means the most positive
          from the sentiments present in the train data. Therefore e.g.
          if train data had only negative sentiment, then
          sentiment\_max, would be still negative (although least
          negative). The sentiment shouldn't be confused with "score" or
          "magnitude" from the previous Natural Language Sentiment
          Analysis API.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextSentimentAnnotation)
    ),
)
_sym_db.RegisterMessage(TextSentimentAnnotation)

TextSentimentEvaluationMetrics = _reflection.GeneratedProtocolMessageType(
    "TextSentimentEvaluationMetrics",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTSENTIMENTEVALUATIONMETRICS,
        __module__="google.cloud.automl_v1beta1.proto.text_sentiment_pb2",
        __doc__="""Model evaluation metrics for text sentiment problems.
  
  
  Attributes:
      precision:
          Output only. Precision.
      recall:
          Output only. Recall.
      f1_score:
          Output only. The harmonic mean of recall and precision.
      mean_absolute_error:
          Output only. Mean absolute error. Only set for the overall
          model evaluation, not for evaluation of a single annotation
          spec.
      mean_squared_error:
          Output only. Mean squared error. Only set for the overall
          model evaluation, not for evaluation of a single annotation
          spec.
      linear_kappa:
          Output only. Linear weighted kappa. Only set for the overall
          model evaluation, not for evaluation of a single annotation
          spec.
      quadratic_kappa:
          Output only. Quadratic weighted kappa. Only set for the
          overall model evaluation, not for evaluation of a single
          annotation spec.
      confusion_matrix:
          Output only. Confusion matrix of the evaluation. Only set for
          the overall model evaluation, not for evaluation of a single
          annotation spec.
      annotation_spec_id:
          Output only. The annotation spec ids used for this evaluation.
          Deprecated, remove after Boq Migration and use then
          TextSentimentModelMetadata.annotation\_spec\_count for count,
          and list all model evaluations to see the exact
          annotation\_spec\_ids that were used.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextSentimentEvaluationMetrics)
    ),
)
_sym_db.RegisterMessage(TextSentimentEvaluationMetrics)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    annotation_payload_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_annotation__payload__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    column_spec_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    dataset_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    image_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_image__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    io_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    model_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    model_evaluation_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__evaluation__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    operations_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_operations__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    table_spec_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/service.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1B\013AutoMlProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n/google/cloud/automl_v1beta1/proto/service.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a:google/cloud/automl_v1beta1/proto/annotation_payload.proto\x1a\x33google/cloud/automl_v1beta1/proto/column_spec.proto\x1a/google/cloud/automl_v1beta1/proto/dataset.proto\x1a-google/cloud/automl_v1beta1/proto/image.proto\x1a*google/cloud/automl_v1beta1/proto/io.proto\x1a-google/cloud/automl_v1beta1/proto/model.proto\x1a\x38google/cloud/automl_v1beta1/proto/model_evaluation.proto\x1a\x32google/cloud/automl_v1beta1/proto/operations.proto\x1a\x32google/cloud/automl_v1beta1/proto/table_spec.proto\x1a#google/longrunning/operations.proto\x1a google/protobuf/field_mask.proto"]\n\x14\x43reateDatasetRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x35\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32$.google.cloud.automl.v1beta1.Dataset"!\n\x11GetDatasetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\\\n\x13ListDatasetsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t"g\n\x14ListDatasetsResponse\x12\x36\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32$.google.cloud.automl.v1beta1.Dataset\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"~\n\x14UpdateDatasetRequest\x12\x35\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32$.google.cloud.automl.v1beta1.Dataset\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"$\n\x14\x44\x65leteDatasetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"a\n\x11ImportDataRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x0cinput_config\x18\x03 \x01(\x0b\x32(.google.cloud.automl.v1beta1.InputConfig"c\n\x11\x45xportDataRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\routput_config\x18\x03 \x01(\x0b\x32).google.cloud.automl.v1beta1.OutputConfig"(\n\x18GetAnnotationSpecRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"S\n\x13GetTableSpecRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"\x8e\x01\n\x15ListTableSpecsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t"n\n\x16ListTableSpecsResponse\x12;\n\x0btable_specs\x18\x01 \x03(\x0b\x32&.google.cloud.automl.v1beta1.TableSpec\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\x85\x01\n\x16UpdateTableSpecRequest\x12:\n\ntable_spec\x18\x01 \x01(\x0b\x32&.google.cloud.automl.v1beta1.TableSpec\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"T\n\x14GetColumnSpecRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"\x8f\x01\n\x16ListColumnSpecsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t"q\n\x17ListColumnSpecsResponse\x12=\n\x0c\x63olumn_specs\x18\x01 \x03(\x0b\x32\'.google.cloud.automl.v1beta1.ColumnSpec\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\x88\x01\n\x17UpdateColumnSpecRequest\x12<\n\x0b\x63olumn_spec\x18\x01 \x01(\x0b\x32\'.google.cloud.automl.v1beta1.ColumnSpec\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"W\n\x12\x43reateModelRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x31\n\x05model\x18\x04 \x01(\x0b\x32".google.cloud.automl.v1beta1.Model"\x1f\n\x0fGetModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"Z\n\x11ListModelsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t"`\n\x12ListModelsResponse\x12\x31\n\x05model\x18\x01 \x03(\x0b\x32".google.cloud.automl.v1beta1.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t""\n\x12\x44\x65leteModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\xc6\x01\n\x12\x44\x65ployModelRequest\x12\x84\x01\n0image_object_detection_model_deployment_metadata\x18\x02 \x01(\x0b\x32H.google.cloud.automl.v1beta1.ImageObjectDetectionModelDeploymentMetadataH\x00\x12\x0c\n\x04name\x18\x01 \x01(\tB\x1b\n\x19model_deployment_metadata"$\n\x14UndeployModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"o\n\x12\x45xportModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12K\n\routput_config\x18\x03 \x01(\x0b\x32\x34.google.cloud.automl.v1beta1.ModelExportOutputConfig"\x87\x01\n\x1e\x45xportEvaluatedExamplesRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12W\n\routput_config\x18\x03 \x01(\x0b\x32@.google.cloud.automl.v1beta1.ExportEvaluatedExamplesOutputConfig")\n\x19GetModelEvaluationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"d\n\x1bListModelEvaluationsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t"\x7f\n\x1cListModelEvaluationsResponse\x12\x46\n\x10model_evaluation\x18\x01 \x03(\x0b\x32,.google.cloud.automl.v1beta1.ModelEvaluation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x8e"\n\x06\x41utoMl\x12\xac\x01\n\rCreateDataset\x12\x31.google.cloud.automl.v1beta1.CreateDatasetRequest\x1a$.google.cloud.automl.v1beta1.Dataset"B\x82\xd3\xe4\x93\x02<"1/v1beta1/{parent=projects/*/locations/*}/datasets:\x07\x64\x61taset\x12\x9d\x01\n\nGetDataset\x12..google.cloud.automl.v1beta1.GetDatasetRequest\x1a$.google.cloud.automl.v1beta1.Dataset"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1beta1/{name=projects/*/locations/*/datasets/*}\x12\xae\x01\n\x0cListDatasets\x12\x30.google.cloud.automl.v1beta1.ListDatasetsRequest\x1a\x31.google.cloud.automl.v1beta1.ListDatasetsResponse"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1beta1/{parent=projects/*/locations/*}/datasets\x12\xb4\x01\n\rUpdateDataset\x12\x31.google.cloud.automl.v1beta1.UpdateDatasetRequest\x1a$.google.cloud.automl.v1beta1.Dataset"J\x82\xd3\xe4\x93\x02\x44\x32\x39/v1beta1/{dataset.name=projects/*/locations/*/datasets/*}:\x07\x64\x61taset\x12\x9c\x01\n\rDeleteDataset\x12\x31.google.cloud.automl.v1beta1.DeleteDatasetRequest\x1a\x1d.google.longrunning.Operation"9\x82\xd3\xe4\x93\x02\x33*1/v1beta1/{name=projects/*/locations/*/datasets/*}\x12\xa4\x01\n\nImportData\x12..google.cloud.automl.v1beta1.ImportDataRequest\x1a\x1d.google.longrunning.Operation"G\x82\xd3\xe4\x93\x02\x41"</v1beta1/{name=projects/*/locations/*/datasets/*}:importData:\x01*\x12\xa4\x01\n\nExportData\x12..google.cloud.automl.v1beta1.ExportDataRequest\x1a\x1d.google.longrunning.Operation"G\x82\xd3\xe4\x93\x02\x41"</v1beta1/{name=projects/*/locations/*/datasets/*}:exportData:\x01*\x12\xc4\x01\n\x11GetAnnotationSpec\x12\x35.google.cloud.automl.v1beta1.GetAnnotationSpecRequest\x1a+.google.cloud.automl.v1beta1.AnnotationSpec"K\x82\xd3\xe4\x93\x02\x45\x12\x43/v1beta1/{name=projects/*/locations/*/datasets/*/annotationSpecs/*}\x12\xb0\x01\n\x0cGetTableSpec\x12\x30.google.cloud.automl.v1beta1.GetTableSpecRequest\x1a&.google.cloud.automl.v1beta1.TableSpec"F\x82\xd3\xe4\x93\x02@\x12>/v1beta1/{name=projects/*/locations/*/datasets/*/tableSpecs/*}\x12\xc1\x01\n\x0eListTableSpecs\x12\x32.google.cloud.automl.v1beta1.ListTableSpecsRequest\x1a\x33.google.cloud.automl.v1beta1.ListTableSpecsResponse"F\x82\xd3\xe4\x93\x02@\x12>/v1beta1/{parent=projects/*/locations/*/datasets/*}/tableSpecs\x12\xcd\x01\n\x0fUpdateTableSpec\x12\x33.google.cloud.automl.v1beta1.UpdateTableSpecRequest\x1a&.google.cloud.automl.v1beta1.TableSpec"]\x82\xd3\xe4\x93\x02W2I/v1beta1/{table_spec.name=projects/*/locations/*/datasets/*/tableSpecs/*}:\ntable_spec\x12\xc1\x01\n\rGetColumnSpec\x12\x31.google.cloud.automl.v1beta1.GetColumnSpecRequest\x1a\'.google.cloud.automl.v1beta1.ColumnSpec"T\x82\xd3\xe4\x93\x02N\x12L/v1beta1/{name=projects/*/locations/*/datasets/*/tableSpecs/*/columnSpecs/*}\x12\xd2\x01\n\x0fListColumnSpecs\x12\x33.google.cloud.automl.v1beta1.ListColumnSpecsRequest\x1a\x34.google.cloud.automl.v1beta1.ListColumnSpecsResponse"T\x82\xd3\xe4\x93\x02N\x12L/v1beta1/{parent=projects/*/locations/*/datasets/*/tableSpecs/*}/columnSpecs\x12\xe0\x01\n\x10UpdateColumnSpec\x12\x34.google.cloud.automl.v1beta1.UpdateColumnSpecRequest\x1a\'.google.cloud.automl.v1beta1.ColumnSpec"m\x82\xd3\xe4\x93\x02g2X/v1beta1/{column_spec.name=projects/*/locations/*/datasets/*/tableSpecs/*/columnSpecs/*}:\x0b\x63olumn_spec\x12\x9d\x01\n\x0b\x43reateModel\x12/.google.cloud.automl.v1beta1.CreateModelRequest\x1a\x1d.google.longrunning.Operation">\x82\xd3\xe4\x93\x02\x38"//v1beta1/{parent=projects/*/locations/*}/models:\x05model\x12\x95\x01\n\x08GetModel\x12,.google.cloud.automl.v1beta1.GetModelRequest\x1a".google.cloud.automl.v1beta1.Model"7\x82\xd3\xe4\x93\x02\x31\x12//v1beta1/{name=projects/*/locations/*/models/*}\x12\xa6\x01\n\nListModels\x12..google.cloud.automl.v1beta1.ListModelsRequest\x1a/.google.cloud.automl.v1beta1.ListModelsResponse"7\x82\xd3\xe4\x93\x02\x31\x12//v1beta1/{parent=projects/*/locations/*}/models\x12\x96\x01\n\x0b\x44\x65leteModel\x12/.google.cloud.automl.v1beta1.DeleteModelRequest\x1a\x1d.google.longrunning.Operation"7\x82\xd3\xe4\x93\x02\x31*//v1beta1/{name=projects/*/locations/*/models/*}\x12\xa0\x01\n\x0b\x44\x65ployModel\x12/.google.cloud.automl.v1beta1.DeployModelRequest\x1a\x1d.google.longrunning.Operation"A\x82\xd3\xe4\x93\x02;"6/v1beta1/{name=projects/*/locations/*/models/*}:deploy:\x01*\x12\xa6\x01\n\rUndeployModel\x12\x31.google.cloud.automl.v1beta1.UndeployModelRequest\x1a\x1d.google.longrunning.Operation"C\x82\xd3\xe4\x93\x02="8/v1beta1/{name=projects/*/locations/*/models/*}:undeploy:\x01*\x12\xa0\x01\n\x0b\x45xportModel\x12/.google.cloud.automl.v1beta1.ExportModelRequest\x1a\x1d.google.longrunning.Operation"A\x82\xd3\xe4\x93\x02;"6/v1beta1/{name=projects/*/locations/*/models/*}:export:\x01*\x12\xc9\x01\n\x17\x45xportEvaluatedExamples\x12;.google.cloud.automl.v1beta1.ExportEvaluatedExamplesRequest\x1a\x1d.google.longrunning.Operation"R\x82\xd3\xe4\x93\x02L"G/v1beta1/{name=projects/*/locations/*/models/*}:exportEvaluatedExamples:\x01*\x12\xc6\x01\n\x12GetModelEvaluation\x12\x36.google.cloud.automl.v1beta1.GetModelEvaluationRequest\x1a,.google.cloud.automl.v1beta1.ModelEvaluation"J\x82\xd3\xe4\x93\x02\x44\x12\x42/v1beta1/{name=projects/*/locations/*/models/*/modelEvaluations/*}\x12\xd7\x01\n\x14ListModelEvaluations\x12\x38.google.cloud.automl.v1beta1.ListModelEvaluationsRequest\x1a\x39.google.cloud.automl.v1beta1.ListModelEvaluationsResponse"J\x82\xd3\xe4\x93\x02\x44\x12\x42/v1beta1/{parent=projects/*/locations/*/models/*}/modelEvaluationsB\x91\x01\n\x1f\x63om.google.cloud.automl.v1beta1B\x0b\x41utoMlProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_annotation__payload__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_image__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__evaluation__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_operations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_CREATEDATASETREQUEST = _descriptor.Descriptor(
    name="CreateDatasetRequest",
    full_name="google.cloud.automl.v1beta1.CreateDatasetRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1beta1.CreateDatasetRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="dataset",
            full_name="google.cloud.automl.v1beta1.CreateDatasetRequest.dataset",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=643,
    serialized_end=736,
)


_GETDATASETREQUEST = _descriptor.Descriptor(
    name="GetDatasetRequest",
    full_name="google.cloud.automl.v1beta1.GetDatasetRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.GetDatasetRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=738,
    serialized_end=771,
)


_LISTDATASETSREQUEST = _descriptor.Descriptor(
    name="ListDatasetsRequest",
    full_name="google.cloud.automl.v1beta1.ListDatasetsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1beta1.ListDatasetsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.automl.v1beta1.ListDatasetsRequest.filter",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.automl.v1beta1.ListDatasetsRequest.page_size",
            index=2,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.automl.v1beta1.ListDatasetsRequest.page_token",
            index=3,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=773,
    serialized_end=865,
)


_LISTDATASETSRESPONSE = _descriptor.Descriptor(
    name="ListDatasetsResponse",
    full_name="google.cloud.automl.v1beta1.ListDatasetsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="datasets",
            full_name="google.cloud.automl.v1beta1.ListDatasetsResponse.datasets",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.automl.v1beta1.ListDatasetsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=867,
    serialized_end=970,
)


_UPDATEDATASETREQUEST = _descriptor.Descriptor(
    name="UpdateDatasetRequest",
    full_name="google.cloud.automl.v1beta1.UpdateDatasetRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="dataset",
            full_name="google.cloud.automl.v1beta1.UpdateDatasetRequest.dataset",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.automl.v1beta1.UpdateDatasetRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=972,
    serialized_end=1098,
)


_DELETEDATASETREQUEST = _descriptor.Descriptor(
    name="DeleteDatasetRequest",
    full_name="google.cloud.automl.v1beta1.DeleteDatasetRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.DeleteDatasetRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1100,
    serialized_end=1136,
)


_IMPORTDATAREQUEST = _descriptor.Descriptor(
    name="ImportDataRequest",
    full_name="google.cloud.automl.v1beta1.ImportDataRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.ImportDataRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="input_config",
            full_name="google.cloud.automl.v1beta1.ImportDataRequest.input_config",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1138,
    serialized_end=1235,
)


_EXPORTDATAREQUEST = _descriptor.Descriptor(
    name="ExportDataRequest",
    full_name="google.cloud.automl.v1beta1.ExportDataRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.ExportDataRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.automl.v1beta1.ExportDataRequest.output_config",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1237,
    serialized_end=1336,
)


_GETANNOTATIONSPECREQUEST = _descriptor.Descriptor(
    name="GetAnnotationSpecRequest",
    full_name="google.cloud.automl.v1beta1.GetAnnotationSpecRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.GetAnnotationSpecRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1338,
    serialized_end=1378,
)


_GETTABLESPECREQUEST = _descriptor.Descriptor(
    name="GetTableSpecRequest",
    full_name="google.cloud.automl.v1beta1.GetTableSpecRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.GetTableSpecRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="field_mask",
            full_name="google.cloud.automl.v1beta1.GetTableSpecRequest.field_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1380,
    serialized_end=1463,
)


_LISTTABLESPECSREQUEST = _descriptor.Descriptor(
    name="ListTableSpecsRequest",
    full_name="google.cloud.automl.v1beta1.ListTableSpecsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1beta1.ListTableSpecsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="field_mask",
            full_name="google.cloud.automl.v1beta1.ListTableSpecsRequest.field_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.automl.v1beta1.ListTableSpecsRequest.filter",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.automl.v1beta1.ListTableSpecsRequest.page_size",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.automl.v1beta1.ListTableSpecsRequest.page_token",
            index=4,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1466,
    serialized_end=1608,
)


_LISTTABLESPECSRESPONSE = _descriptor.Descriptor(
    name="ListTableSpecsResponse",
    full_name="google.cloud.automl.v1beta1.ListTableSpecsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="table_specs",
            full_name="google.cloud.automl.v1beta1.ListTableSpecsResponse.table_specs",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.automl.v1beta1.ListTableSpecsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1610,
    serialized_end=1720,
)


_UPDATETABLESPECREQUEST = _descriptor.Descriptor(
    name="UpdateTableSpecRequest",
    full_name="google.cloud.automl.v1beta1.UpdateTableSpecRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="table_spec",
            full_name="google.cloud.automl.v1beta1.UpdateTableSpecRequest.table_spec",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.automl.v1beta1.UpdateTableSpecRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1723,
    serialized_end=1856,
)


_GETCOLUMNSPECREQUEST = _descriptor.Descriptor(
    name="GetColumnSpecRequest",
    full_name="google.cloud.automl.v1beta1.GetColumnSpecRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.GetColumnSpecRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="field_mask",
            full_name="google.cloud.automl.v1beta1.GetColumnSpecRequest.field_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1858,
    serialized_end=1942,
)


_LISTCOLUMNSPECSREQUEST = _descriptor.Descriptor(
    name="ListColumnSpecsRequest",
    full_name="google.cloud.automl.v1beta1.ListColumnSpecsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1beta1.ListColumnSpecsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="field_mask",
            full_name="google.cloud.automl.v1beta1.ListColumnSpecsRequest.field_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.automl.v1beta1.ListColumnSpecsRequest.filter",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.automl.v1beta1.ListColumnSpecsRequest.page_size",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.automl.v1beta1.ListColumnSpecsRequest.page_token",
            index=4,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1945,
    serialized_end=2088,
)


_LISTCOLUMNSPECSRESPONSE = _descriptor.Descriptor(
    name="ListColumnSpecsResponse",
    full_name="google.cloud.automl.v1beta1.ListColumnSpecsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="column_specs",
            full_name="google.cloud.automl.v1beta1.ListColumnSpecsResponse.column_specs",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.automl.v1beta1.ListColumnSpecsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2090,
    serialized_end=2203,
)


_UPDATECOLUMNSPECREQUEST = _descriptor.Descriptor(
    name="UpdateColumnSpecRequest",
    full_name="google.cloud.automl.v1beta1.UpdateColumnSpecRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="column_spec",
            full_name="google.cloud.automl.v1beta1.UpdateColumnSpecRequest.column_spec",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.automl.v1beta1.UpdateColumnSpecRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2206,
    serialized_end=2342,
)


_CREATEMODELREQUEST = _descriptor.Descriptor(
    name="CreateModelRequest",
    full_name="google.cloud.automl.v1beta1.CreateModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1beta1.CreateModelRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="model",
            full_name="google.cloud.automl.v1beta1.CreateModelRequest.model",
            index=1,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2344,
    serialized_end=2431,
)


_GETMODELREQUEST = _descriptor.Descriptor(
    name="GetModelRequest",
    full_name="google.cloud.automl.v1beta1.GetModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.GetModelRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2433,
    serialized_end=2464,
)


_LISTMODELSREQUEST = _descriptor.Descriptor(
    name="ListModelsRequest",
    full_name="google.cloud.automl.v1beta1.ListModelsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1beta1.ListModelsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.automl.v1beta1.ListModelsRequest.filter",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.automl.v1beta1.ListModelsRequest.page_size",
            index=2,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.automl.v1beta1.ListModelsRequest.page_token",
            index=3,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2466,
    serialized_end=2556,
)


_LISTMODELSRESPONSE = _descriptor.Descriptor(
    name="ListModelsResponse",
    full_name="google.cloud.automl.v1beta1.ListModelsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="model",
            full_name="google.cloud.automl.v1beta1.ListModelsResponse.model",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.automl.v1beta1.ListModelsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2558,
    serialized_end=2654,
)


_DELETEMODELREQUEST = _descriptor.Descriptor(
    name="DeleteModelRequest",
    full_name="google.cloud.automl.v1beta1.DeleteModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.DeleteModelRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2656,
    serialized_end=2690,
)


_DEPLOYMODELREQUEST = _descriptor.Descriptor(
    name="DeployModelRequest",
    full_name="google.cloud.automl.v1beta1.DeployModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="image_object_detection_model_deployment_metadata",
            full_name="google.cloud.automl.v1beta1.DeployModelRequest.image_object_detection_model_deployment_metadata",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.DeployModelRequest.name",
            index=1,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="model_deployment_metadata",
            full_name="google.cloud.automl.v1beta1.DeployModelRequest.model_deployment_metadata",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=2693,
    serialized_end=2891,
)


_UNDEPLOYMODELREQUEST = _descriptor.Descriptor(
    name="UndeployModelRequest",
    full_name="google.cloud.automl.v1beta1.UndeployModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.UndeployModelRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2893,
    serialized_end=2929,
)


_EXPORTMODELREQUEST = _descriptor.Descriptor(
    name="ExportModelRequest",
    full_name="google.cloud.automl.v1beta1.ExportModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.ExportModelRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.automl.v1beta1.ExportModelRequest.output_config",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2931,
    serialized_end=3042,
)


_EXPORTEVALUATEDEXAMPLESREQUEST = _descriptor.Descriptor(
    name="ExportEvaluatedExamplesRequest",
    full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.automl.v1beta1.ExportEvaluatedExamplesRequest.output_config",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3045,
    serialized_end=3180,
)


_GETMODELEVALUATIONREQUEST = _descriptor.Descriptor(
    name="GetModelEvaluationRequest",
    full_name="google.cloud.automl.v1beta1.GetModelEvaluationRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.GetModelEvaluationRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3182,
    serialized_end=3223,
)


_LISTMODELEVALUATIONSREQUEST = _descriptor.Descriptor(
    name="ListModelEvaluationsRequest",
    full_name="google.cloud.automl.v1beta1.ListModelEvaluationsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1beta1.ListModelEvaluationsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.automl.v1beta1.ListModelEvaluationsRequest.filter",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.automl.v1beta1.ListModelEvaluationsRequest.page_size",
            index=2,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.automl.v1beta1.ListModelEvaluationsRequest.page_token",
            index=3,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3225,
    serialized_end=3325,
)


_LISTMODELEVALUATIONSRESPONSE = _descriptor.Descriptor(
    name="ListModelEvaluationsResponse",
    full_name="google.cloud.automl.v1beta1.ListModelEvaluationsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="model_evaluation",
            full_name="google.cloud.automl.v1beta1.ListModelEvaluationsResponse.model_evaluation",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.automl.v1beta1.ListModelEvaluationsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3327,
    serialized_end=3454,
)

_CREATEDATASETREQUEST.fields_by_name[
    "dataset"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2._DATASET
)
_LISTDATASETSRESPONSE.fields_by_name[
    "datasets"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2._DATASET
)
_UPDATEDATASETREQUEST.fields_by_name[
    "dataset"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2._DATASET
)
_UPDATEDATASETREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_IMPORTDATAREQUEST.fields_by_name[
    "input_config"
].message_type = google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._INPUTCONFIG
_EXPORTDATAREQUEST.fields_by_name[
    "output_config"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._OUTPUTCONFIG
)
_GETTABLESPECREQUEST.fields_by_name[
    "field_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTTABLESPECSREQUEST.fields_by_name[
    "field_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTTABLESPECSRESPONSE.fields_by_name[
    "table_specs"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2._TABLESPEC
)
_UPDATETABLESPECREQUEST.fields_by_name[
    "table_spec"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2._TABLESPEC
)
_UPDATETABLESPECREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_GETCOLUMNSPECREQUEST.fields_by_name[
    "field_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTCOLUMNSPECSREQUEST.fields_by_name[
    "field_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTCOLUMNSPECSRESPONSE.fields_by_name[
    "column_specs"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2._COLUMNSPEC
)
_UPDATECOLUMNSPECREQUEST.fields_by_name[
    "column_spec"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2._COLUMNSPEC
)
_UPDATECOLUMNSPECREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CREATEMODELREQUEST.fields_by_name[
    "model"
].message_type = google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2._MODEL
_LISTMODELSRESPONSE.fields_by_name[
    "model"
].message_type = google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2._MODEL
_DEPLOYMODELREQUEST.fields_by_name[
    "image_object_detection_model_deployment_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_image__pb2._IMAGEOBJECTDETECTIONMODELDEPLOYMENTMETADATA
)
_DEPLOYMODELREQUEST.oneofs_by_name["model_deployment_metadata"].fields.append(
    _DEPLOYMODELREQUEST.fields_by_name[
        "image_object_detection_model_deployment_metadata"
    ]
)
_DEPLOYMODELREQUEST.fields_by_name[
    "image_object_detection_model_deployment_metadata"
].containing_oneof = _DEPLOYMODELREQUEST.oneofs_by_name["model_deployment_metadata"]
_EXPORTMODELREQUEST.fields_by_name[
    "output_config"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._MODELEXPORTOUTPUTCONFIG
)
_EXPORTEVALUATEDEXAMPLESREQUEST.fields_by_name[
    "output_config"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._EXPORTEVALUATEDEXAMPLESOUTPUTCONFIG
)
_LISTMODELEVALUATIONSRESPONSE.fields_by_name[
    "model_evaluation"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__evaluation__pb2._MODELEVALUATION
)
DESCRIPTOR.message_types_by_name["CreateDatasetRequest"] = _CREATEDATASETREQUEST
DESCRIPTOR.message_types_by_name["GetDatasetRequest"] = _GETDATASETREQUEST
DESCRIPTOR.message_types_by_name["ListDatasetsRequest"] = _LISTDATASETSREQUEST
DESCRIPTOR.message_types_by_name["ListDatasetsResponse"] = _LISTDATASETSRESPONSE
DESCRIPTOR.message_types_by_name["UpdateDatasetRequest"] = _UPDATEDATASETREQUEST
DESCRIPTOR.message_types_by_name["DeleteDatasetRequest"] = _DELETEDATASETREQUEST
DESCRIPTOR.message_types_by_name["ImportDataRequest"] = _IMPORTDATAREQUEST
DESCRIPTOR.message_types_by_name["ExportDataRequest"] = _EXPORTDATAREQUEST
DESCRIPTOR.message_types_by_name["GetAnnotationSpecRequest"] = _GETANNOTATIONSPECREQUEST
DESCRIPTOR.message_types_by_name["GetTableSpecRequest"] = _GETTABLESPECREQUEST
DESCRIPTOR.message_types_by_name["ListTableSpecsRequest"] = _LISTTABLESPECSREQUEST
DESCRIPTOR.message_types_by_name["ListTableSpecsResponse"] = _LISTTABLESPECSRESPONSE
DESCRIPTOR.message_types_by_name["UpdateTableSpecRequest"] = _UPDATETABLESPECREQUEST
DESCRIPTOR.message_types_by_name["GetColumnSpecRequest"] = _GETCOLUMNSPECREQUEST
DESCRIPTOR.message_types_by_name["ListColumnSpecsRequest"] = _LISTCOLUMNSPECSREQUEST
DESCRIPTOR.message_types_by_name["ListColumnSpecsResponse"] = _LISTCOLUMNSPECSRESPONSE
DESCRIPTOR.message_types_by_name["UpdateColumnSpecRequest"] = _UPDATECOLUMNSPECREQUEST
DESCRIPTOR.message_types_by_name["CreateModelRequest"] = _CREATEMODELREQUEST
DESCRIPTOR.message_types_by_name["GetModelRequest"] = _GETMODELREQUEST
DESCRIPTOR.message_types_by_name["ListModelsRequest"] = _LISTMODELSREQUEST
DESCRIPTOR.message_types_by_name["ListModelsResponse"] = _LISTMODELSRESPONSE
DESCRIPTOR.message_types_by_name["DeleteModelRequest"] = _DELETEMODELREQUEST
DESCRIPTOR.message_types_by_name["DeployModelRequest"] = _DEPLOYMODELREQUEST
DESCRIPTOR.message_types_by_name["UndeployModelRequest"] = _UNDEPLOYMODELREQUEST
DESCRIPTOR.message_types_by_name["ExportModelRequest"] = _EXPORTMODELREQUEST
DESCRIPTOR.message_types_by_name[
    "ExportEvaluatedExamplesRequest"
] = _EXPORTEVALUATEDEXAMPLESREQUEST
DESCRIPTOR.message_types_by_name[
    "GetModelEvaluationRequest"
] = _GETMODELEVALUATIONREQUEST
DESCRIPTOR.message_types_by_name[
    "ListModelEvaluationsRequest"
] = _LISTMODELEVALUATIONSREQUEST
DESCRIPTOR.message_types_by_name[
    "ListModelEvaluationsResponse"
] = _LISTMODELEVALUATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType(
    "CreateDatasetRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEDATASETREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.CreateDataset][google.cloud.automl.v1beta1.AutoMl.CreateDataset].
  
  
  Attributes:
      parent:
          The resource name of the project to create the dataset for.
      dataset:
          The dataset to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.CreateDatasetRequest)
    ),
)
_sym_db.RegisterMessage(CreateDatasetRequest)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType(
    "GetDatasetRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETDATASETREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetDataset][google.cloud.automl.v1beta1.AutoMl.GetDataset].
  
  
  Attributes:
      name:
          The resource name of the dataset to retrieve.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.GetDatasetRequest)
    ),
)
_sym_db.RegisterMessage(GetDatasetRequest)

ListDatasetsRequest = _reflection.GeneratedProtocolMessageType(
    "ListDatasetsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTDATASETSREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ListDatasets][google.cloud.automl.v1beta1.AutoMl.ListDatasets].
  
  
  Attributes:
      parent:
          The resource name of the project from which to list datasets.
      filter:
          An expression for filtering the results of the request.  -
          ``dataset_metadata`` - for existence of the case (e.g.
          image\_classification\_dataset\_metadata:\*). Some examples of
          using    the filter are:  -
          ``translation_dataset_metadata:*`` --> The dataset has
          translation\_dataset\_metadata.
      page_size:
          Requested page size. Server may return fewer results than
          requested. If unspecified, server will pick a default size.
      page_token:
          A token identifying a page of results for the server to return
          Typically obtained via [ListDatasetsResponse.next\_page\_token
          ][google.cloud.automl.v1beta1.ListDatasetsResponse.next\_page\
          _token] of the previous [AutoMl.ListDatasets][google.cloud.aut
          oml.v1beta1.AutoMl.ListDatasets] call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListDatasetsRequest)
    ),
)
_sym_db.RegisterMessage(ListDatasetsRequest)

ListDatasetsResponse = _reflection.GeneratedProtocolMessageType(
    "ListDatasetsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTDATASETSRESPONSE,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Response message for
  [AutoMl.ListDatasets][google.cloud.automl.v1beta1.AutoMl.ListDatasets].
  
  
  Attributes:
      datasets:
          The datasets read.
      next_page_token:
          A token to retrieve next page of results. Pass to [ListDataset
          sRequest.page\_token][google.cloud.automl.v1beta1.ListDatasets
          Request.page\_token] to obtain that page.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListDatasetsResponse)
    ),
)
_sym_db.RegisterMessage(ListDatasetsResponse)

UpdateDatasetRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateDatasetRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATEDATASETREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.UpdateDataset][google.cloud.automl.v1beta1.AutoMl.UpdateDataset]
  
  
  Attributes:
      dataset:
          The dataset which replaces the resource on the server.
      update_mask:
          The update mask applies to the resource. For the ``FieldMask``
          definition, see  https: //developers.google.com/protocol-
          buffers // /docs/reference/google.protobuf#fieldmask
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.UpdateDatasetRequest)
    ),
)
_sym_db.RegisterMessage(UpdateDatasetRequest)

DeleteDatasetRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteDatasetRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEDATASETREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.DeleteDataset][google.cloud.automl.v1beta1.AutoMl.DeleteDataset].
  
  
  Attributes:
      name:
          The resource name of the dataset to delete.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.DeleteDatasetRequest)
    ),
)
_sym_db.RegisterMessage(DeleteDatasetRequest)

ImportDataRequest = _reflection.GeneratedProtocolMessageType(
    "ImportDataRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMPORTDATAREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ImportData][google.cloud.automl.v1beta1.AutoMl.ImportData].
  
  
  Attributes:
      name:
          Required. Dataset name. Dataset must already exist. All
          imported annotations and examples will be added.
      input_config:
          Required. The desired input location and its domain specific
          semantics, if any.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ImportDataRequest)
    ),
)
_sym_db.RegisterMessage(ImportDataRequest)

ExportDataRequest = _reflection.GeneratedProtocolMessageType(
    "ExportDataRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EXPORTDATAREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ExportData][google.cloud.automl.v1beta1.AutoMl.ExportData].
  
  
  Attributes:
      name:
          Required. The resource name of the dataset.
      output_config:
          Required. The desired output location.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportDataRequest)
    ),
)
_sym_db.RegisterMessage(ExportDataRequest)

GetAnnotationSpecRequest = _reflection.GeneratedProtocolMessageType(
    "GetAnnotationSpecRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETANNOTATIONSPECREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetAnnotationSpec][google.cloud.automl.v1beta1.AutoMl.GetAnnotationSpec].
  
  
  Attributes:
      name:
          The resource name of the annotation spec to retrieve.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.GetAnnotationSpecRequest)
    ),
)
_sym_db.RegisterMessage(GetAnnotationSpecRequest)

GetTableSpecRequest = _reflection.GeneratedProtocolMessageType(
    "GetTableSpecRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETTABLESPECREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetTableSpec][google.cloud.automl.v1beta1.AutoMl.GetTableSpec].
  
  
  Attributes:
      name:
          The resource name of the table spec to retrieve.
      field_mask:
          Mask specifying which fields to read.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.GetTableSpecRequest)
    ),
)
_sym_db.RegisterMessage(GetTableSpecRequest)

ListTableSpecsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTableSpecsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTTABLESPECSREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ListTableSpecs][google.cloud.automl.v1beta1.AutoMl.ListTableSpecs].
  
  
  Attributes:
      parent:
          The resource name of the dataset to list table specs from.
      field_mask:
          Mask specifying which fields to read.
      filter:
          Filter expression, see go/filtering.
      page_size:
          Requested page size. The server can return fewer results than
          requested. If unspecified, the server will pick a default
          size.
      page_token:
          A token identifying a page of results for the server to
          return. Typically obtained from the [ListTableSpecsResponse.ne
          xt\_page\_token][google.cloud.automl.v1beta1.ListTableSpecsRes
          ponse.next\_page\_token] field of the previous [AutoMl.ListTab
          leSpecs][google.cloud.automl.v1beta1.AutoMl.ListTableSpecs]
          call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListTableSpecsRequest)
    ),
)
_sym_db.RegisterMessage(ListTableSpecsRequest)

ListTableSpecsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTableSpecsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTTABLESPECSRESPONSE,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Response message for
  [AutoMl.ListTableSpecs][google.cloud.automl.v1beta1.AutoMl.ListTableSpecs].
  
  
  Attributes:
      table_specs:
          The table specs read.
      next_page_token:
          A token to retrieve next page of results. Pass to [ListTableSp
          ecsRequest.page\_token][google.cloud.automl.v1beta1.ListTableS
          pecsRequest.page\_token] to obtain that page.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListTableSpecsResponse)
    ),
)
_sym_db.RegisterMessage(ListTableSpecsResponse)

UpdateTableSpecRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTableSpecRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATETABLESPECREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.UpdateTableSpec][google.cloud.automl.v1beta1.AutoMl.UpdateTableSpec]
  
  
  Attributes:
      table_spec:
          The table spec which replaces the resource on the server.
      update_mask:
          The update mask applies to the resource. For the ``FieldMask``
          definition, see  https: //developers.google.com/protocol-
          buffers // /docs/reference/google.protobuf#fieldmask
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.UpdateTableSpecRequest)
    ),
)
_sym_db.RegisterMessage(UpdateTableSpecRequest)

GetColumnSpecRequest = _reflection.GeneratedProtocolMessageType(
    "GetColumnSpecRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETCOLUMNSPECREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetColumnSpec][google.cloud.automl.v1beta1.AutoMl.GetColumnSpec].
  
  
  Attributes:
      name:
          The resource name of the column spec to retrieve.
      field_mask:
          Mask specifying which fields to read.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.GetColumnSpecRequest)
    ),
)
_sym_db.RegisterMessage(GetColumnSpecRequest)

ListColumnSpecsRequest = _reflection.GeneratedProtocolMessageType(
    "ListColumnSpecsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTCOLUMNSPECSREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ListColumnSpecs][google.cloud.automl.v1beta1.AutoMl.ListColumnSpecs].
  
  
  Attributes:
      parent:
          The resource name of the table spec to list column specs from.
      field_mask:
          Mask specifying which fields to read.
      filter:
          Filter expression, see go/filtering.
      page_size:
          Requested page size. The server can return fewer results than
          requested. If unspecified, the server will pick a default
          size.
      page_token:
          A token identifying a page of results for the server to
          return. Typically obtained from the [ListColumnSpecsResponse.n
          ext\_page\_token][google.cloud.automl.v1beta1.ListColumnSpecsR
          esponse.next\_page\_token] field of the previous [AutoMl.ListC
          olumnSpecs][google.cloud.automl.v1beta1.AutoMl.ListColumnSpecs
          ] call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListColumnSpecsRequest)
    ),
)
_sym_db.RegisterMessage(ListColumnSpecsRequest)

ListColumnSpecsResponse = _reflection.GeneratedProtocolMessageType(
    "ListColumnSpecsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTCOLUMNSPECSRESPONSE,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Response message for
  [AutoMl.ListColumnSpecs][google.cloud.automl.v1beta1.AutoMl.ListColumnSpecs].
  
  
  Attributes:
      column_specs:
          The column specs read.
      next_page_token:
          A token to retrieve next page of results. Pass to [ListColumnS
          pecsRequest.page\_token][google.cloud.automl.v1beta1.ListColum
          nSpecsRequest.page\_token] to obtain that page.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListColumnSpecsResponse)
    ),
)
_sym_db.RegisterMessage(ListColumnSpecsResponse)

UpdateColumnSpecRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateColumnSpecRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATECOLUMNSPECREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.UpdateColumnSpec][google.cloud.automl.v1beta1.AutoMl.UpdateColumnSpec]
  
  
  Attributes:
      column_spec:
          The column spec which replaces the resource on the server.
      update_mask:
          The update mask applies to the resource. For the ``FieldMask``
          definition, see  https: //developers.google.com/protocol-
          buffers // /docs/reference/google.protobuf#fieldmask
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.UpdateColumnSpecRequest)
    ),
)
_sym_db.RegisterMessage(UpdateColumnSpecRequest)

CreateModelRequest = _reflection.GeneratedProtocolMessageType(
    "CreateModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEMODELREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.CreateModel][google.cloud.automl.v1beta1.AutoMl.CreateModel].
  
  
  Attributes:
      parent:
          Resource name of the parent project where the model is being
          created.
      model:
          The model to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.CreateModelRequest)
    ),
)
_sym_db.RegisterMessage(CreateModelRequest)

GetModelRequest = _reflection.GeneratedProtocolMessageType(
    "GetModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETMODELREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetModel][google.cloud.automl.v1beta1.AutoMl.GetModel].
  
  
  Attributes:
      name:
          Resource name of the model.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.GetModelRequest)
    ),
)
_sym_db.RegisterMessage(GetModelRequest)

ListModelsRequest = _reflection.GeneratedProtocolMessageType(
    "ListModelsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTMODELSREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ListModels][google.cloud.automl.v1beta1.AutoMl.ListModels].
  
  
  Attributes:
      parent:
          Resource name of the project, from which to list the models.
      filter:
          An expression for filtering the results of the request.  -
          ``model_metadata`` - for existence of the case (e.g.
          video\_classification\_model\_metadata:\*). -  ``dataset_id``
          - for = or !=. Some examples of using the filter are:  -
          ``image_classification_model_metadata:*`` --> The model has
          image\_classification\_model\_metadata. -  ``dataset_id=5``
          --> The model was created from a dataset with ID 5.
      page_size:
          Requested page size.
      page_token:
          A token identifying a page of results for the server to return
          Typically obtained via [ListModelsResponse.next\_page\_token][
          google.cloud.automl.v1beta1.ListModelsResponse.next\_page\_tok
          en] of the previous [AutoMl.ListModels][google.cloud.automl.v1
          beta1.AutoMl.ListModels] call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListModelsRequest)
    ),
)
_sym_db.RegisterMessage(ListModelsRequest)

ListModelsResponse = _reflection.GeneratedProtocolMessageType(
    "ListModelsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTMODELSRESPONSE,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Response message for
  [AutoMl.ListModels][google.cloud.automl.v1beta1.AutoMl.ListModels].
  
  
  Attributes:
      model:
          List of models in the requested page.
      next_page_token:
          A token to retrieve next page of results. Pass to [ListModelsR
          equest.page\_token][google.cloud.automl.v1beta1.ListModelsRequ
          est.page\_token] to obtain that page.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListModelsResponse)
    ),
)
_sym_db.RegisterMessage(ListModelsResponse)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEMODELREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.DeleteModel][google.cloud.automl.v1beta1.AutoMl.DeleteModel].
  
  
  Attributes:
      name:
          Resource name of the model being deleted.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.DeleteModelRequest)
    ),
)
_sym_db.RegisterMessage(DeleteModelRequest)

DeployModelRequest = _reflection.GeneratedProtocolMessageType(
    "DeployModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DEPLOYMODELREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.DeployModel][google.cloud.automl.v1beta1.AutoMl.DeployModel].
  
  
  Attributes:
      model_deployment_metadata:
          The per-domain specific deployment parameters.
      image_object_detection_model_deployment_metadata:
          Model deployment metadata specific to Image Object Detection.
      name:
          Resource name of the model to deploy.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.DeployModelRequest)
    ),
)
_sym_db.RegisterMessage(DeployModelRequest)

UndeployModelRequest = _reflection.GeneratedProtocolMessageType(
    "UndeployModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UNDEPLOYMODELREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.UndeployModel][google.cloud.automl.v1beta1.AutoMl.UndeployModel].
  
  
  Attributes:
      name:
          Resource name of the model to undeploy.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.UndeployModelRequest)
    ),
)
_sym_db.RegisterMessage(UndeployModelRequest)

ExportModelRequest = _reflection.GeneratedProtocolMessageType(
    "ExportModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EXPORTMODELREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ExportModel][google.cloud.automl.v1beta1.AutoMl.ExportModel].
  Models need to be enabled for exporting, otherwise an error code will be
  returned.
  
  
  Attributes:
      name:
          Required. The resource name of the model to export.
      output_config:
          Required. The desired output location and configuration.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportModelRequest)
    ),
)
_sym_db.RegisterMessage(ExportModelRequest)

ExportEvaluatedExamplesRequest = _reflection.GeneratedProtocolMessageType(
    "ExportEvaluatedExamplesRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EXPORTEVALUATEDEXAMPLESREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ExportEvaluatedExamples][google.cloud.automl.v1beta1.AutoMl.ExportEvaluatedExamples].
  
  
  Attributes:
      name:
          Required. The resource name of the model whose evaluated
          examples are to be exported.
      output_config:
          Required. The desired output location and configuration.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExportEvaluatedExamplesRequest)
    ),
)
_sym_db.RegisterMessage(ExportEvaluatedExamplesRequest)

GetModelEvaluationRequest = _reflection.GeneratedProtocolMessageType(
    "GetModelEvaluationRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETMODELEVALUATIONREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetModelEvaluation][google.cloud.automl.v1beta1.AutoMl.GetModelEvaluation].
  
  
  Attributes:
      name:
          Resource name for the model evaluation.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.GetModelEvaluationRequest)
    ),
)
_sym_db.RegisterMessage(GetModelEvaluationRequest)

ListModelEvaluationsRequest = _reflection.GeneratedProtocolMessageType(
    "ListModelEvaluationsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTMODELEVALUATIONSREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ListModelEvaluations][google.cloud.automl.v1beta1.AutoMl.ListModelEvaluations].
  
  
  Attributes:
      parent:
          Resource name of the model to list the model evaluations for.
          If modelId is set as "-", this will list model evaluations
          from across all models of the parent location.
      filter:
          An expression for filtering the results of the request.  -
          ``annotation_spec_id`` - for =, != or existence. See example
          below    for the last.  Some examples of using the filter are:
          -  ``annotation_spec_id!=4`` --> The model evaluation was done
          for    annotation spec with ID different than 4. -  ``NOT
          annotation_spec_id:*`` --> The model evaluation was done for
          aggregate of all annotation specs.
      page_size:
          Requested page size.
      page_token:
          A token identifying a page of results for the server to
          return. Typically obtained via [ListModelEvaluationsResponse.n
          ext\_page\_token][google.cloud.automl.v1beta1.ListModelEvaluat
          ionsResponse.next\_page\_token] of the previous [AutoMl.ListMo
          delEvaluations][google.cloud.automl.v1beta1.AutoMl.ListModelEv
          aluations] call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListModelEvaluationsRequest)
    ),
)
_sym_db.RegisterMessage(ListModelEvaluationsRequest)

ListModelEvaluationsResponse = _reflection.GeneratedProtocolMessageType(
    "ListModelEvaluationsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTMODELEVALUATIONSRESPONSE,
        __module__="google.cloud.automl_v1beta1.proto.service_pb2",
        __doc__="""Response message for
  [AutoMl.ListModelEvaluations][google.cloud.automl.v1beta1.AutoMl.ListModelEvaluations].
  
  
  Attributes:
      model_evaluation:
          List of model evaluations in the requested page.
      next_page_token:
          A token to retrieve next page of results. Pass to the [ListMod
          elEvaluationsRequest.page\_token][google.cloud.automl.v1beta1.
          ListModelEvaluationsRequest.page\_token] field of a new [AutoM
          l.ListModelEvaluations][google.cloud.automl.v1beta1.AutoMl.Lis
          tModelEvaluations] request to obtain that page.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ListModelEvaluationsResponse)
    ),
)
_sym_db.RegisterMessage(ListModelEvaluationsResponse)


DESCRIPTOR._options = None

_AUTOML = _descriptor.ServiceDescriptor(
    name="AutoMl",
    full_name="google.cloud.automl.v1beta1.AutoMl",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    serialized_start=3457,
    serialized_end=7823,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateDataset",
            full_name="google.cloud.automl.v1beta1.AutoMl.CreateDataset",
            index=0,
            containing_service=None,
            input_type=_CREATEDATASETREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2._DATASET,
            serialized_options=_b(
                '\202\323\344\223\002<"1/v1beta1/{parent=projects/*/locations/*}/datasets:\007dataset'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetDataset",
            full_name="google.cloud.automl.v1beta1.AutoMl.GetDataset",
            index=1,
            containing_service=None,
            input_type=_GETDATASETREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2._DATASET,
            serialized_options=_b(
                "\202\323\344\223\0023\0221/v1beta1/{name=projects/*/locations/*/datasets/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListDatasets",
            full_name="google.cloud.automl.v1beta1.AutoMl.ListDatasets",
            index=2,
            containing_service=None,
            input_type=_LISTDATASETSREQUEST,
            output_type=_LISTDATASETSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\0023\0221/v1beta1/{parent=projects/*/locations/*}/datasets"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateDataset",
            full_name="google.cloud.automl.v1beta1.AutoMl.UpdateDataset",
            index=3,
            containing_service=None,
            input_type=_UPDATEDATASETREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2._DATASET,
            serialized_options=_b(
                "\202\323\344\223\002D29/v1beta1/{dataset.name=projects/*/locations/*/datasets/*}:\007dataset"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteDataset",
            full_name="google.cloud.automl.v1beta1.AutoMl.DeleteDataset",
            index=4,
            containing_service=None,
            input_type=_DELETEDATASETREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                "\202\323\344\223\0023*1/v1beta1/{name=projects/*/locations/*/datasets/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ImportData",
            full_name="google.cloud.automl.v1beta1.AutoMl.ImportData",
            index=5,
            containing_service=None,
            input_type=_IMPORTDATAREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002A"</v1beta1/{name=projects/*/locations/*/datasets/*}:importData:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ExportData",
            full_name="google.cloud.automl.v1beta1.AutoMl.ExportData",
            index=6,
            containing_service=None,
            input_type=_EXPORTDATAREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002A"</v1beta1/{name=projects/*/locations/*/datasets/*}:exportData:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetAnnotationSpec",
            full_name="google.cloud.automl.v1beta1.AutoMl.GetAnnotationSpec",
            index=7,
            containing_service=None,
            input_type=_GETANNOTATIONSPECREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2._ANNOTATIONSPEC,
            serialized_options=_b(
                "\202\323\344\223\002E\022C/v1beta1/{name=projects/*/locations/*/datasets/*/annotationSpecs/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetTableSpec",
            full_name="google.cloud.automl.v1beta1.AutoMl.GetTableSpec",
            index=8,
            containing_service=None,
            input_type=_GETTABLESPECREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2._TABLESPEC,
            serialized_options=_b(
                "\202\323\344\223\002@\022>/v1beta1/{name=projects/*/locations/*/datasets/*/tableSpecs/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListTableSpecs",
            full_name="google.cloud.automl.v1beta1.AutoMl.ListTableSpecs",
            index=9,
            containing_service=None,
            input_type=_LISTTABLESPECSREQUEST,
            output_type=_LISTTABLESPECSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002@\022>/v1beta1/{parent=projects/*/locations/*/datasets/*}/tableSpecs"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTableSpec",
            full_name="google.cloud.automl.v1beta1.AutoMl.UpdateTableSpec",
            index=10,
            containing_service=None,
            input_type=_UPDATETABLESPECREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2._TABLESPEC,
            serialized_options=_b(
                "\202\323\344\223\002W2I/v1beta1/{table_spec.name=projects/*/locations/*/datasets/*/tableSpecs/*}:\ntable_spec"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetColumnSpec",
            full_name="google.cloud.automl.v1beta1.AutoMl.GetColumnSpec",
            index=11,
            containing_service=None,
            input_type=_GETCOLUMNSPECREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2._COLUMNSPEC,
            serialized_options=_b(
                "\202\323\344\223\002N\022L/v1beta1/{name=projects/*/locations/*/datasets/*/tableSpecs/*/columnSpecs/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListColumnSpecs",
            full_name="google.cloud.automl.v1beta1.AutoMl.ListColumnSpecs",
            index=12,
            containing_service=None,
            input_type=_LISTCOLUMNSPECSREQUEST,
            output_type=_LISTCOLUMNSPECSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002N\022L/v1beta1/{parent=projects/*/locations/*/datasets/*/tableSpecs/*}/columnSpecs"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateColumnSpec",
            full_name="google.cloud.automl.v1beta1.AutoMl.UpdateColumnSpec",
            index=13,
            containing_service=None,
            input_type=_UPDATECOLUMNSPECREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2._COLUMNSPEC,
            serialized_options=_b(
                "\202\323\344\223\002g2X/v1beta1/{column_spec.name=projects/*/locations/*/datasets/*/tableSpecs/*/columnSpecs/*}:\013column_spec"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="CreateModel",
            full_name="google.cloud.automl.v1beta1.AutoMl.CreateModel",
            index=14,
            containing_service=None,
            input_type=_CREATEMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\0028"//v1beta1/{parent=projects/*/locations/*}/models:\005model'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetModel",
            full_name="google.cloud.automl.v1beta1.AutoMl.GetModel",
            index=15,
            containing_service=None,
            input_type=_GETMODELREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2._MODEL,
            serialized_options=_b(
                "\202\323\344\223\0021\022//v1beta1/{name=projects/*/locations/*/models/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListModels",
            full_name="google.cloud.automl.v1beta1.AutoMl.ListModels",
            index=16,
            containing_service=None,
            input_type=_LISTMODELSREQUEST,
            output_type=_LISTMODELSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\0021\022//v1beta1/{parent=projects/*/locations/*}/models"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteModel",
            full_name="google.cloud.automl.v1beta1.AutoMl.DeleteModel",
            index=17,
            containing_service=None,
            input_type=_DELETEMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                "\202\323\344\223\0021*//v1beta1/{name=projects/*/locations/*/models/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeployModel",
            full_name="google.cloud.automl.v1beta1.AutoMl.DeployModel",
            index=18,
            containing_service=None,
            input_type=_DEPLOYMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002;"6/v1beta1/{name=projects/*/locations/*/models/*}:deploy:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UndeployModel",
            full_name="google.cloud.automl.v1beta1.AutoMl.UndeployModel",
            index=19,
            containing_service=None,
            input_type=_UNDEPLOYMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002="8/v1beta1/{name=projects/*/locations/*/models/*}:undeploy:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ExportModel",
            full_name="google.cloud.automl.v1beta1.AutoMl.ExportModel",
            index=20,
            containing_service=None,
            input_type=_EXPORTMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002;"6/v1beta1/{name=projects/*/locations/*/models/*}:export:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ExportEvaluatedExamples",
            full_name="google.cloud.automl.v1beta1.AutoMl.ExportEvaluatedExamples",
            index=21,
            containing_service=None,
            input_type=_EXPORTEVALUATEDEXAMPLESREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002L"G/v1beta1/{name=projects/*/locations/*/models/*}:exportEvaluatedExamples:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetModelEvaluation",
            full_name="google.cloud.automl.v1beta1.AutoMl.GetModelEvaluation",
            index=22,
            containing_service=None,
            input_type=_GETMODELEVALUATIONREQUEST,
            output_type=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__evaluation__pb2._MODELEVALUATION,
            serialized_options=_b(
                "\202\323\344\223\002D\022B/v1beta1/{name=projects/*/locations/*/models/*/modelEvaluations/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListModelEvaluations",
            full_name="google.cloud.automl.v1beta1.AutoMl.ListModelEvaluations",
            index=23,
            containing_service=None,
            input_type=_LISTMODELEVALUATIONSREQUEST,
            output_type=_LISTMODELEVALUATIONSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002D\022B/v1beta1/{parent=projects/*/locations/*/models/*}/modelEvaluations"
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_AUTOML)

DESCRIPTOR.services_by_name["AutoMl"] = _AUTOML

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/text.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    classification_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/text.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1B\tTextProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n,google/cloud/automl_v1beta1/proto/text.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x36google/cloud/automl_v1beta1/proto/classification.proto"q\n!TextClassificationDatasetMetadata\x12L\n\x13\x63lassification_type\x18\x01 \x01(\x0e\x32/.google.cloud.automl.v1beta1.ClassificationType"!\n\x1fTextClassificationModelMetadata"\x1f\n\x1dTextExtractionDatasetMetadata"\x1d\n\x1bTextExtractionModelMetadata"5\n\x1cTextSentimentDatasetMetadata\x12\x15\n\rsentiment_max\x18\x01 \x01(\x05"\x1c\n\x1aTextSentimentModelMetadataB\x8f\x01\n\x1f\x63om.google.cloud.automl.v1beta1B\tTextProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2.DESCRIPTOR,
    ],
)


_TEXTCLASSIFICATIONDATASETMETADATA = _descriptor.Descriptor(
    name="TextClassificationDatasetMetadata",
    full_name="google.cloud.automl.v1beta1.TextClassificationDatasetMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="classification_type",
            full_name="google.cloud.automl.v1beta1.TextClassificationDatasetMetadata.classification_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=163,
    serialized_end=276,
)


_TEXTCLASSIFICATIONMODELMETADATA = _descriptor.Descriptor(
    name="TextClassificationModelMetadata",
    full_name="google.cloud.automl.v1beta1.TextClassificationModelMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=278,
    serialized_end=311,
)


_TEXTEXTRACTIONDATASETMETADATA = _descriptor.Descriptor(
    name="TextExtractionDatasetMetadata",
    full_name="google.cloud.automl.v1beta1.TextExtractionDatasetMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=313,
    serialized_end=344,
)


_TEXTEXTRACTIONMODELMETADATA = _descriptor.Descriptor(
    name="TextExtractionModelMetadata",
    full_name="google.cloud.automl.v1beta1.TextExtractionModelMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=346,
    serialized_end=375,
)


_TEXTSENTIMENTDATASETMETADATA = _descriptor.Descriptor(
    name="TextSentimentDatasetMetadata",
    full_name="google.cloud.automl.v1beta1.TextSentimentDatasetMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="sentiment_max",
            full_name="google.cloud.automl.v1beta1.TextSentimentDatasetMetadata.sentiment_max",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=377,
    serialized_end=430,
)


_TEXTSENTIMENTMODELMETADATA = _descriptor.Descriptor(
    name="TextSentimentModelMetadata",
    full_name="google.cloud.automl.v1beta1.TextSentimentModelMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=432,
    serialized_end=460,
)

_TEXTCLASSIFICATIONDATASETMETADATA.fields_by_name[
    "classification_type"
].enum_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_classification__pb2._CLASSIFICATIONTYPE
)
DESCRIPTOR.message_types_by_name[
    "TextClassificationDatasetMetadata"
] = _TEXTCLASSIFICATIONDATASETMETADATA
DESCRIPTOR.message_types_by_name[
    "TextClassificationModelMetadata"
] = _TEXTCLASSIFICATIONMODELMETADATA
DESCRIPTOR.message_types_by_name[
    "TextExtractionDatasetMetadata"
] = _TEXTEXTRACTIONDATASETMETADATA
DESCRIPTOR.message_types_by_name[
    "TextExtractionModelMetadata"
] = _TEXTEXTRACTIONMODELMETADATA
DESCRIPTOR.message_types_by_name[
    "TextSentimentDatasetMetadata"
] = _TEXTSENTIMENTDATASETMETADATA
DESCRIPTOR.message_types_by_name[
    "TextSentimentModelMetadata"
] = _TEXTSENTIMENTMODELMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextClassificationDatasetMetadata = _reflection.GeneratedProtocolMessageType(
    "TextClassificationDatasetMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTCLASSIFICATIONDATASETMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.text_pb2",
        __doc__="""Dataset metadata for classification.
  
  
  Attributes:
      classification_type:
          Required. Type of the classification problem.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextClassificationDatasetMetadata)
    ),
)
_sym_db.RegisterMessage(TextClassificationDatasetMetadata)

TextClassificationModelMetadata = _reflection.GeneratedProtocolMessageType(
    "TextClassificationModelMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTCLASSIFICATIONMODELMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.text_pb2",
        __doc__="""Model metadata that is specific to text classification.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextClassificationModelMetadata)
    ),
)
_sym_db.RegisterMessage(TextClassificationModelMetadata)

TextExtractionDatasetMetadata = _reflection.GeneratedProtocolMessageType(
    "TextExtractionDatasetMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTEXTRACTIONDATASETMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.text_pb2",
        __doc__="""Dataset metadata that is specific to text extraction
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextExtractionDatasetMetadata)
    ),
)
_sym_db.RegisterMessage(TextExtractionDatasetMetadata)

TextExtractionModelMetadata = _reflection.GeneratedProtocolMessageType(
    "TextExtractionModelMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTEXTRACTIONMODELMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.text_pb2",
        __doc__="""Model metadata that is specific to text extraction.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextExtractionModelMetadata)
    ),
)
_sym_db.RegisterMessage(TextExtractionModelMetadata)

TextSentimentDatasetMetadata = _reflection.GeneratedProtocolMessageType(
    "TextSentimentDatasetMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTSENTIMENTDATASETMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.text_pb2",
        __doc__="""Dataset metadata for text sentiment.
  
  
  Attributes:
      sentiment_max:
          Required. A sentiment is expressed as an integer ordinal,
          where higher value means a more positive sentiment. The range
          of sentiments that will be used is between 0 and
          sentiment\_max (inclusive on both ends), and all the values in
          the range must be represented in the dataset before a model
          can be created. sentiment\_max value must be between 1 and 10
          (inclusive).
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextSentimentDatasetMetadata)
    ),
)
_sym_db.RegisterMessage(TextSentimentDatasetMetadata)

TextSentimentModelMetadata = _reflection.GeneratedProtocolMessageType(
    "TextSentimentModelMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTSENTIMENTMODELMETADATA,
        __module__="google.cloud.automl_v1beta1.proto.text_pb2",
        __doc__="""Model metadata that is specific to text classification.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextSentimentModelMetadata)
    ),
)
_sym_db.RegisterMessage(TextSentimentModelMetadata)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
